@@ -144,46 +144,3 @@ def remove_empty(file_list):
         (list) list of (non None or empty string) contents.
     """
     return [x for x in file_list if x not in ["", None]]
-
-
-def save_results(check_results, file_path, sep=",", header=None):
-    """
-    Given a check_results dictionary, a dict with "failed" and "passed" keys (
-    or more generally, keys to indicate some status), save a csv
-    file that has header with URL,RESULT that indicates, for each url,
-    a pass or failure. If the directory of the file path doesn't exist, exit
-    on error.
-
-    Args:
-        - check_results (dict): the check results dictionary with passed/failed
-        - file_path (str): the file path (.csv) to save to.
-        - sep (str): the separate to use (defaults to comma)
-        - header (list): if not provided, will save URL,RESULT
-
-    Returns:
-        (str) file_path: a newly saved csv with the results
-    """
-    # Ensure that the directory exists
-    file_path = os.path.abspath(file_path)
-    dirname = os.path.dirname(file_path)
-
-    if not os.path.exists(dirname):
-        sys.exit("%s does not exist, cannot save %s there." % (dirname, file_path))
-
-    # Ensure the header is provided and correct (length 2)
-    if not header:
-        header = ["URL", "RESULT"]
-
-    if len(header) != 2:
-        sys.exit("Header must be length 2 to match size of data.")
-
-    print("Saving results to %s" % file_path)
-
-    # Write to file after header row
-    with open(file_path, mode="w") as fd:
-        writer = csv.writer(fd, delimiter=sep, quotechar='"', quoting=csv.QUOTE_MINIMAL)
-        writer.writerow(header)
-        for result, items in check_results.items():
-            [writer.writerow([item, result]) for item in items]
-
-    return file_path
